.. _contributors:

Getting Started
===============

Setup your dev environment with the following commands.

.. code-block:: bash

    git clone git@github.com:Emsu/prophet.git
    cd prophet
    virtualenv env
    pip install dev-requirements.txt
    python setup.py develop


If you want to help with longer term development, please open an issue `here <https://github.com/Emsu/prophet/issues>`_
